@@ -4,8 +4,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-use vars qw($implementation @loops $VERSION);
-$VERSION = '0.07';
+our $VERSION = '0.09';
 
 =head1 NAME
 
@@ -13,7 +12,7 @@ Chrome::DevToolsProtocol::Transport - choose the best transport backend
 
 =cut
 
-@loops = (
+our @loops = (
     ['Mojo/IOLoop.pm' => 'Chrome::DevToolsProtocol::Transport::Mojo' ],
     ['AnyEvent.pm'    => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
     ['AE.pm'          => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
@@ -23,6 +22,7 @@ Chrome::DevToolsProtocol::Transport - choose the best transport backend
     # The fallback, will always catch due to loading strict (for now)
     ['strict.pm'      => 'Chrome::DevToolsProtocol::Transport::AnyEvent'],
 );
+our $implementation;
 
 =head1 METHODS
 
@@ -66,4 +66,33 @@ sub best_implementation( $class, @candidates ) {
     };
 };
 
-1;
\ No newline at end of file
+1;
+
+=head1 REPOSITORY
+
+The public repository of this module is
+L<https://github.com/Corion/www-mechanize-chrome>.
+
+=head1 SUPPORT
+
+The public support forum of this module is L<https://perlmonks.org/>.
+
+=head1 BUG TRACKER
+
+Please report bugs in this module via the RT CPAN bug queue at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=WWW-Mechanize-Chrome>
+or via mail to L<www-mechanize-Chrome-Bugs@rt.cpan.org|mailto:www-mechanize-Chrome-Bugs@rt.cpan.org>.
+
+=head1 AUTHOR
+
+Max Maischein C<corion@cpan.org>
+
+=head1 COPYRIGHT (c)
+
+Copyright 2010-2018 by Max Maischein C<corion@cpan.org>.
+
+=head1 LICENSE
+
+This module is released under the same terms as Perl itself.
+
+=cut
